summaryrefslogtreecommitdiffstats
path: root/karbon/commands/vshapecmd.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:32:11 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:32:11 -0600
commit94844816550ad672ccfcdc25659c625546239998 (patch)
treee35fc60fd736c645d59f6408af032774ad8023d3 /karbon/commands/vshapecmd.h
parent2a811c38c74c03648ecf857e566c44483cbad706 (diff)
downloadkoffice-94844816550ad672ccfcdc25659c625546239998.tar.gz
koffice-94844816550ad672ccfcdc25659c625546239998.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'karbon/commands/vshapecmd.h')
-rw-r--r--karbon/commands/vshapecmd.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/karbon/commands/vshapecmd.h b/karbon/commands/vshapecmd.h
index 30607fcd..d4742a67 100644
--- a/karbon/commands/vshapecmd.h
+++ b/karbon/commands/vshapecmd.h
@@ -28,13 +28,13 @@ class VPath;
/*
* Provides a common base class for creation commands since they all have
* a similar execute / unexecute behaviour and all build a VPath. Upon
* execution() the tqshape will be added to the document and selected, upon undoing
* it will be set to the deleted state.
*/
class KARBONCOMMAND_EXPORT VShapeCmd : public VCommand
{
public:
- VShapeCmd( VDocument* doc, const TQString& name, VPath* tqshape, const TQString& icon = "14_polygon" );
+ VShapeCmd( VDocument* doc, const TQString& name, VPath* shape, const TQString& icon = "14_polygon" );
virtual ~VShapeCmd() {}
virtual void execute();
@@ -43,8 +43,8 @@ public:
virtual bool changesSelection() const { return true; }
protected:
- /// Pointer to the created tqshape.
- VPath *m_tqshape;
+ /// Pointer to the created shape.
+ VPath *m_shape;
};
#endif
@@ -28,13 +28,13 @@ class VPath;
* Provides a common base class for creation commands since they all have
* a similar execute / unexecute behaviour and all build a VPath. Upon
- * execution() the tqshape will be added to the document and selected, upon undoing
+ * execution() the shape will be added to the document and selected, upon undoing
* it will be set to the deleted state.
*/